DirReceiverLocalServerHandler

Trait DirReceiverLocalServerHandler 

pub trait DirReceiverLocalServerHandler<___T: Transport = Channel> {
    // Required method
    fn receive(
        &mut self,
        request: Request<Receive, ___T>,
    ) -> impl Future<Output = ()>;

    // Provided method
    fn on_unknown_interaction(
        &mut self,
        ordinal: u64,
    ) -> impl Future<Output = ()> { ... }
}
A server handler for the DirReceiver protocol.

See DirReceiver for more details.

Required Methods

fn receive( &mut self, request: Request<Receive, ___T>, ) -> impl Future<Output = ()>

Sends a directory channel to this receiver.

The server should implement this method by forwarding channel to a vfs instance of the language appropriate vfs library.

Provided Methods

fn on_unknown_interaction(&mut self, ordinal: u64) -> impl Future<Output = ()>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<___H, ___T> DirReceiverLocalServerHandler<___T> for Local<___H>
where ___H: DirReceiverServerHandler<___T>, ___T: Transport,

Source

async fn receive(&mut self, request: Request<Receive, ___T>)

Source

async fn on_unknown_interaction(&mut self, ordinal: u64)

Implementors